import { HttpClient, NonNullablePaths, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { SubjectInviteAssignments, CreateInviteOptions, CreateInviteResponse } from './index.typings.js';
export { AcceptAccountInviteRequest, AcceptAccountInviteResponse, AccountInvite, AccountInviteRequest, AccountInviteResponse, AccountResourceContext, BulkAccountInviteRequest, BulkAccountInviteResponse, Condition, ConditionOperator, ConditionOperatorOperatorsOneOf, ConditionType, ConditionTypeOfOneOf, ConditionValue, ConditionValueValueOneOf, CreateInviteRequest, DependOnOperator, EnvironmentCondition, EnvironmentConditionConditionOneOf, EqualOperator, ExperimentCondition, ExperimentOperator, FullNameResource, FullNameResourceResourceContextOneOf, GetAccountInviteRequest, GetAccountInviteResponse, GetAccountInvitesRequest, GetAccountInvitesResponse, InviteAssignment, InviteFailure, InviteResourceAssignment, InviteStatus, JoinedCondition, JoinedConditionOperator, LikeOperator, OrganizationResourceContext, ParseAccountInviteTokenRequest, ParseAccountInviteTokenResponse, PolicyCondition, ResendAccountInviteRequest, Resource, RevokeAccountInviteRequest, RevokeAccountInviteResponse, SimpleCondition, SimpleConditionOperator, SimpleConditionValue, SimpleConditionValueValueOneOf, SiteResourceContext, Subject, SubjectContext, SubjectContextType, SubjectType, UpdateAccountInviteAssignmentsRequest, UpdateAccountInviteAssignmentsResponse, UpdateAccountInviteRequest, UpdateAccountInviteResponse } from './index.typings.js';

type AccountInviteNonNullablePaths = `_id` | `accountId` | `email` | `role` | `inviterId` | `status` | `acceptLink` | `inviterAccountId` | `policyIds` | `assignments` | `assignments.${number}.policyId`;
declare function createInvite$1(httpClient: HttpClient): CreateInviteSignature;
interface CreateInviteSignature {
    /**
     * Creates and sends invite emails to a list of potential team members, inviting them to become team members of the requesting account.
     * The invites may be limited to a specific resource (site or other asset).
     * Maximum 50 invitees can be specified per call.
     *
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - Array of potential team members' email addresses and their corresponding assignments (how they will be assigned when they accept the invite).
     * @param - Filter options.
     */
    (subjectsAssignments: SubjectInviteAssignments[], options?: CreateInviteOptions): Promise<NonNullablePaths<CreateInviteResponse, {
        [P in AccountInviteNonNullablePaths]: `successfulInvites.${number}.${P}`;
    }[AccountInviteNonNullablePaths] | `failedInvites` | `failedInvites.${number}.subjectEmail` | `failedInvites.${number}.errorMessage`>>;
}

declare const createInvite: MaybeContext<BuildRESTFunction<typeof createInvite$1> & typeof createInvite$1>;

export { CreateInviteOptions, CreateInviteResponse, SubjectInviteAssignments, createInvite };
