// src/identity-invites-v1-account-invite-account-invites.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/identity-invites-v1-account-invite-account-invites.http.ts
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressInvitesApiAccountInvitesApiUrl(opts) {
  const domainToMappings = {
    "www._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/invites-web",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      },
      {
        srcPath: "/invites",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/invites/invites/site",
        destPath: "/invites/site"
      },
      {
        srcPath: "/invites/invites/account",
        destPath: "/invites/account"
      },
      {
        srcPath: "/invites",
        destPath: ""
      },
      {
        srcPath: "/invites/site-invite",
        destPath: "/site-invite"
      },
      {
        srcPath: "/invites/account-invite",
        destPath: "/account-invite"
      }
    ],
    "dev._base_domain_": [
      {
        srcPath: "/_api/invites-web",
        destPath: ""
      }
    ],
    "platform.rise.ai": [
      {
        srcPath: "/invites/site",
        destPath: "/invites/site"
      },
      {
        srcPath: "/site-invite",
        destPath: "/site-invite"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_user-management_account-invites";
function createInvite(payload) {
  function __createInvite({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.invites.v1.account_invite",
      method: "POST",
      methodFqn: "com.wixpress.invites.api.AccountInvitesApi.CreateInvite",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressInvitesApiAccountInvitesApiUrl({
        protoPath: "/account-invite/create",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "successfulInvites.dateCreated" },
            { path: "successfulInvites.dateUpdated" },
            { path: "successfulInvites.expirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createInvite;
}

// src/identity-invites-v1-account-invite-account-invites.universal.ts
var InviteStatus = /* @__PURE__ */ ((InviteStatus2) => {
  InviteStatus2["Pending"] = "Pending";
  InviteStatus2["Used"] = "Used";
  InviteStatus2["Deleted"] = "Deleted";
  InviteStatus2["Declined"] = "Declined";
  InviteStatus2["Expired"] = "Expired";
  return InviteStatus2;
})(InviteStatus || {});
var SimpleConditionOperator = /* @__PURE__ */ ((SimpleConditionOperator2) => {
  SimpleConditionOperator2["UNKNOWN_SIMPLE_OP"] = "UNKNOWN_SIMPLE_OP";
  SimpleConditionOperator2["EQUAL"] = "EQUAL";
  return SimpleConditionOperator2;
})(SimpleConditionOperator || {});
var JoinedConditionOperator = /* @__PURE__ */ ((JoinedConditionOperator2) => {
  JoinedConditionOperator2["UNKNOWN_JOIN_OP"] = "UNKNOWN_JOIN_OP";
  JoinedConditionOperator2["OR"] = "OR";
  JoinedConditionOperator2["AND"] = "AND";
  return JoinedConditionOperator2;
})(JoinedConditionOperator || {});
var SubjectType = /* @__PURE__ */ ((SubjectType2) => {
  SubjectType2["UNKNOWN"] = "UNKNOWN";
  SubjectType2["ACCOUNT"] = "ACCOUNT";
  SubjectType2["USER"] = "USER";
  SubjectType2["USER_GROUP"] = "USER_GROUP";
  SubjectType2["MEMBER_GROUP"] = "MEMBER_GROUP";
  SubjectType2["VISITOR_GROUP"] = "VISITOR_GROUP";
  SubjectType2["EXTERNAL_APP"] = "EXTERNAL_APP";
  SubjectType2["ACCOUNT_GROUP"] = "ACCOUNT_GROUP";
  SubjectType2["WIX_APP"] = "WIX_APP";
  return SubjectType2;
})(SubjectType || {});
var SubjectContextType = /* @__PURE__ */ ((SubjectContextType2) => {
  SubjectContextType2["UNKNOWN_CTX"] = "UNKNOWN_CTX";
  SubjectContextType2["ORG_CTX"] = "ORG_CTX";
  SubjectContextType2["ACCOUNT_CTX"] = "ACCOUNT_CTX";
  return SubjectContextType2;
})(SubjectContextType || {});
async function createInvite2(subjectsAssignments, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    subjectsAssignments,
    defaultEmailLanguage: options?.defaultEmailLanguage
  });
  const reqOpts = createInvite(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          subjectsAssignments: "$[0]",
          defaultEmailLanguage: "$[1].defaultEmailLanguage"
        },
        singleArgumentUnchanged: false
      },
      ["subjectsAssignments", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
export {
  InviteStatus,
  JoinedConditionOperator,
  SimpleConditionOperator,
  SubjectContextType,
  SubjectType,
  createInvite2 as createInvite
};
//# sourceMappingURL=index.typings.mjs.map